//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by PenCore.rc
//
#define IDOK3                           2
#define B_POLICY                        3
#define B_SAVE                          3
#define B_ABOUT                         3
#define B_OFFLINE                       3
#define IDOK2                           3
#define IDCANCEL3                       3
#define B_WEB                           3
#define B_SIMULATION                    3
#define B_RESTORE                       3
#define B_MESSAGE                       3
#define B_PUSH                          3
#define B_HUB_STATUS                    4
#define IDCANCEL2                       4
#define B_SECURE_MANAGER                4
#define B_REDIRECT                      4
#define B_EULA                          4
#define DLG_SECURE                      5
#define D_SECURE                        5
#define B_CLIENT_CERT                   5
#define B_CREATE                        5
#define B_SELECT_SECURE                 5
#define B_IMPORTANT                     5
#define B_CREATE_LISTENER               6
#define B_CERT_TOOL                     6
#define B_LEGAL                         6
#define B_DELETE_LISTENER               7
#define B_LEGAL2                        7
#define B_UPDATE_CONFIG                 7
#define B_START                         8
#define B_LEGAL3                        8
#define B_LANGUAGE                      8
#define B_STOP                          9
#define B_AUTHORS                       9
#define B_EDIT                          10
#define S_STATUSBAR                     101
#define ICO_TEST                        103
#define BMP_TEST                        104
#define ICO_KEY                         105
#define BMP_SECURE                      106
#define BMP_SECURE2                     107
#define AVI_PROGRESS                    108
#define ICO_CERT                        109
#define D_PKCSUTIL                      110
#define D_PASSPHRASE                    111
#define D_DEFAULT                       112
#define D_SPEEDMETER                    112
#define D_PASSWORD                      113
#define ICO_SERVER_ONLINE               113
#define D_STATUS                        114
#define D_CERT                          115
#define D_CHECKCERT                     116
#define ICO_WARNING                     117
#define D_CONNECTERROR                  117
#define ICO_NULL                        118
#define D_CM_LOGIN                      118
#define D_CM_MAIN                       119
#define ICO_TOWER                       119
#define ICO_VPN                         120
#define D_CONNECTION_STATUS             120
#define ICO_VPNSERVER                   121
#define D_CM_POLICY                     121
#define D_CM_ACCOUNT                    122
#define ICO_NIC_ONLINE                  123
#define D_CM_PROXY                      123
#define ICO_SETUP                       124
#define D_CM_DETAIL                     124
#define ICO_MACHINE                     125
#define D_CM_NEW_VLAN                   125
#define D_CM_TRUST                      126
#define D_CM_PASSWORD                   127
#define ICO_HUB                         128
#define D_CM_CONFIG                     128
#define ICO_VLAN                        129
#define D_ABOUT                         129
#define ICO_SERVER_OFFLINE              130
#define M_MAIN                          130
#define D_REMOTE                        130
#define ICO_NIC_OFFLINE                 131
#define D_CM_DESKTOP                    131
#define D_CM_CHANGE_PASSWORD            132
#define ICO_INFORMATION                 133
#define D_SM_MAIN                       133
#define ICO_STOP                        134
#define D_SM_EDIT_SETTING               134
#define ICO_SERVER_DELETE               135
#define D_SM_SERVER                     135
#define ICO_SERVER_ONLINE_EX            136
#define D_SM_STATUS                     136
#define ICO_SERVER_OFFLINE_EX           137
#define D_SM_EDIT_HUB                   137
#define ICO_INTERNET                    138
#define D_SM_CREATE_LISTENER            138
#define ICO_DISPLAY                     139
#define D_SM_SSL                        139
#define D_SM_SAVE_KEY_PAIR              140
#define BMP_MANAGER_LOGO                141
#define D_SM_CONNECTION                 141
#define D_SM_FARM                       142
#define ICO_GROUP                       143
#define D_SM_FARM_MEMBER                143
#define ICO_USER                        144
#define D_SM_CHANGE_PASSWORD            144
#define ICO_USER_ADMIN                  145
#define D_SM_HUB                        145
#define ICO_HUB_OFFLINE                 146
#define D_SM_USER                       146
#define ICO_FARM                        147
#define D_SM_EDIT_USER                  147
#define D_SM_POLICY                     148
#define D_SM_GROUP                      149
#define ICO_X                           150
#define D_SM_EDIT_GROUP                 150
#define ICO_PROTOCOL                    151
#define D_SM_ACCESS_LIST                151
#define ICO_PROTOCOL_X                  152
#define D_SM_EDIT_ACCESS                152
#define ICO_DISCARD                     153
#define D_SM_RADIUS                     153
#define ICO_PASS                        154
#define D_SM_LINK                       154
#define ICO_PROTOCOL_OFFLINE            155
#define D_SM_LOG                        155
#define ICO_MEMORY                      156
#define D_SM_CA                         156
#define ICO_PKCS12                      157
#define D_SM_SESSION                    157
#define ICO_SERVER_CERT                 158
#define D_SM_MAC                        158
#define D_SM_IP                         159
#define ICO_LINK                        160
#define D_SM_CREATE_CERT                160
#define ICO_PENGUIN                     161
#define D_NM_LOGIN                      161
#define ICO_LINK2                       162
#define ICO_CASCADE                     163
#define ICO_USER1                       164
#define ICO_USER_DENY                   164
#define ICO_GROUP_DENY                  165
#define ICO_LOG                         166
#define ICO_LOG2                        167
#define ICO_DATETIME                    168
#define ICO_NEW                         169
#define ICO_PASS_DISABLE                170
#define ICO_DISCARD_DISABLE             171
#define ICO_CASCADE_ERROR               172
#define ICO_CASCADE_OFFLINE             173
#define ICO_PROTOCOL_DHCP               174
#define ICO_ROUTER                      175
#define BMP_ROUTER_BANNER               176
#define BMP_ROUTER_LOGO                 178
#define BMP_COINS                       179
#define ICO_BRIDGE                      180
#define BIN_WINPCAP                     181
#define ICO_SWITCH                      182
#define ICO_SWITCH_OFFLINE              183
#define ICO_SECURE                      184
#define ICO_CERT_X                      185
#define ICO_INTERNET_X                  186
#define ICO_LICENSE                     187
#define ICO_SESSION_BRIDGE              188
#define BMP_SECURE3                     188
#define ICO_VPN1                        189
#define ICO_SESSION_MONITOR             189
#define ICO_TRAY1                       190
#define BMP_CLIENT_BANNER               190
#define ICO_TRAY2                       191
#define BMP_SETUP_2                     191
#define ICO_TRAY3                       192
#define BMP_SETUP_1                     192
#define ICO_TRAY4                       193
#define BMP_TSUKUBA                     193
#define ICO_VPN2                        194
#define ICO_TRAY0                       194
#define IDR_MENU1                       194
#define M_VOICE_BACKUP                  194
#define BMP_ETHERIP                     195
#define BMP_L2TP                        197
#define ICO_IPSEC                       201
#define BMP_IX2015                      202
#define ICO_DDNS                        203
#define ICO_OPENVPN                     204
#define BMP_OPENVPN                     205
#define BMP_SSTP                        206
#define ICO_SPECIALLISTENER             207
#define BMP_SPECIALLISTENER             208
#define ICO_INSTALLER                   209
#define BMP_SELOGO49x49                 211
#define ICO_LANGUAGE                    215
#define BMP_SW_LANG_1                   216
#define BMP_SW_LANG_2                   217
#define BMP_SW_LANG_3                   218
#define ICO_LANG_CHINESE                219
#define ICO_LANG_ENGLISH                220
#define ICO_LANG_JAPANESE               221
#define ICO_EASYINSTALLER               222
#define BMP_VPNSERVER_FIGURE            223
#define BMP_ABOUTBOX                    224
#define BMP_UPDATE                      225
#define BMP_IBARAKI                     226
#define IDB_BITMAP1                     227
#define BMP_WINPC                       227
#define BMP_VMBRIDGE                    228
#define BMP_AZURE                       229
#define BMP_AZURE_JA                    230
#define ICO_AZURE                       231
#define IDB_BITMAP2                     232
#define BMP_AZURE_CN                    232
#define ICO_ZURUHAM                     233
#define IDI_ICON2                       234
#define ICO_ZURUKKO                     234
#define BMP_VPNGATEBANNER               235
#define BMP_ZURUKKO                     236
#define BMP_VPNGATEEN                   237
#define BMP_VPNGATEJA                   238
#define ICO_RESEARCH                    239
#define BMP_UNIVTSUKUBA                 240
#define ICO_POLICE                      241
#define S_TITLE                         1007
#define S_INSERT_SECURE                 1008
#define S_TITLE2                        1008
#define S_STATIC                        1008
#define S_RESEARCH                      1008
#define S_DEVICE_INFO                   1009
#define E_PIN                           1010
#define IDS_STATIC1                     1012
#define S_WARNING                       1013
#define A_PROGRESS                      1014
#define S_MSG_1                         1014
#define S_WARNING2                      1014
#define S_STATUS                        1015
#define S_MSG_2                         1015
#define S_PIN_CODE                      1016
#define S_MSG_3                         1016
#define S_STATUS3                       1016
#define S_SOFTWARE_TITLE                1017
#define S_STATUS4                       1017
#define B_WRITE                         1018
#define S_STATUS6                       1018
#define B_ERASE                         1019
#define S_STATUS5                       1019
#define S_COPYRIGHT                     1020
#define S_SUFFIX                        1020
#define E_PASSPHRASE                    1021
#define S_STATUS7                       1021
#define S_STATUS8                       1022
#define E_USERNAME                      1023
#define C_TYPE                          1024
#define E_HUBNAME                       1024
#define E_REALNAME                      1024
#define P_PROGRESS                      1025
#define E_NOTE                          1025
#define E_NICNAME                       1025
#define E_GROUP                         1026
#define E_PRIORITY                      1026
#define E_PASSWORD                      1027
#define E_CN                            1027
#define E_SRC_IP_V6                     1027
#define S_COUNTDOWN                     1028
#define E_PASSWORD2                     1028
#define E_SRC_PORT_1                    1028
#define E_O                             1028
#define S_RETRYINFO                     1029
#define E_RADIUS_USERNAME               1029
#define E_SRC_PORT_2                    1029
#define E_OU                            1029
#define E_SUBJECT                       1030
#define E_DST_PORT_1                    1030
#define E_C                             1030
#define E_ISSUER                        1031
#define E_DST_PORT_2                    1031
#define E_ST                            1031
#define E_EXPIRES                       1032
#define E_L                             1032
#define E_SRC_PORT_3                    1032
#define E_IP_PROTO                      1032
#define L_CERTINFO                      1033
#define E_MD5                           1033
#define E_EXPIRES_TIME                  1033
#define E_EXPIRE                        1033
#define E_SERI                          1033
#define E_DST_MAC                       1033
#define S_PARENT                        1034
#define E_DOMAIN                        1034
#define E_MD5_HASH                      1034
#define E_SRC_MAC                       1034
#define B_PARENT                        1035
#define E_SHA1                          1035
#define E_SHA1_HASH                     1035
#define E_SRC_MAC_MASK                  1035
#define E_DST_MAC_MASK                  1036
#define S_WARNING_ICON                  1037
#define E_SRC_MASK_V6                   1037
#define S_CERT_ICON                     1038
#define E_DST_IP_V6                     1038
#define S_PARENT_BUTTON_STR             1039
#define E_DST_MASK_V6                   1039
#define E_DETAIL                        1040
#define B_SHOW                          1041
#define S_MSG1                          1043
#define E_ERROR                         1044
#define L_ACCOUNT                       1047
#define L_VLAN                          1048
#define L_STATUS                        1048
#define S_DESCRIPTION                   1051
#define L_POLICY                        1052
#define E_ACCOUNT_NAME                  1053
#define E_HOSTNAME                      1054
#define E_RETRY_NUM                     1055
#define E_SECRET1                       1055
#define E_SECRET2                       1056
#define R_DIRECT_TCP                    1057
#define R_HTTPS                         1059
#define R_SOCKS                         1060
#define S_USERNAME                      1062
#define E_RETRY_SPAN                    1065
#define C_HUBNAME                       1066
#define S_PASSWORD                      1067
#define S_CERT                          1068
#define S_CONTROLLER_PORT               1068
#define B_REGIST_CLIENT_CERT            1069
#define S_CERT_INFO                     1070
#define R_RETRY                         1071
#define R_INFINITE                      1072
#define R_USE_ENCRYPT                   1072
#define B_DETAIL                        1073
#define R_USE_COMPRESS                  1073
#define R_CHECK_CERT                    1074
#define R_USE_COMPRESS2                 1074
#define R_DISABLE_UDP                   1074
#define B_CONFIG_L2                     1074
#define B_VIEW_CLIENT_CERT              1075
#define C_NUM_TCP                       1075
#define B_TRUST                         1076
#define E_INTERVAL                      1076
#define B_PROXY_CONFIG                  1077
#define B_SERVER_CERT                   1078
#define B_VIEW_SERVER_CERT              1079
#define R_USE_HALF_CONNECTION           1080
#define C_PORT                          1080
#define S_STATIC13                      1080
#define R_USE_DISCONNECT                1081
#define S_RETRY_NUM_1                   1081
#define S_RETRY_NUM_2                   1082
#define S_RETRY_SPAN_1                  1083
#define E_DISCONNECT_SPAN               1083
#define S_RETRY_SPAN_2                  1084
#define R_NO_ROUTING                    1084
#define E_NAME                          1085
#define B_CHANGE_PASSWORD               1085
#define L_CERT                          1086
#define S_CHANGE_PASSWORD               1086
#define B_IMPORT                        1087
#define B_PROXY_CONFIG2                 1087
#define B_IE                            1087
#define B_EXPORT                        1088
#define IDC_STATIC1                     1088
#define R_R_NOTLS1                      1088
#define R_NOTLS1                        1088
#define R_USE_PASSWORD                  1089
#define IDC_STATIC3                     1089
#define B_IMPORT2                       1089
#define B_REGENERATE                    1089
#define B_FACTORY                       1089
#define R_RETRY2                        1089
#define R_REMOTE_ONLY                   1090
#define IDC_STATIC4                     1090
#define B_DELETE                        1091
#define IDC_STATIC2                     1091
#define R_ALLOW_REMOTE_CONFIG           1092
#define B_REFRESH                       1092
#define IDC_STATIC5                     1092
#define B_DELETE2                       1092
#define B_ETH_VLAN                      1092
#define B_VLAN                          1092
#define R_USE_KEEP_CONNECT              1093
#define B_CERT                          1093
#define IDC_STATIC6                     1093
#define B_SESSION_IP_TABLE              1093
#define B_NEW_CERT                      1093
#define B_RENAME                        1093
#define S_HOSTNAME                      1094
#define B_REFRESH2                      1094
#define B_BRIDGE                        1094
#define B_PIN                           1094
#define R_ALPHA                         1095
#define B_SESSION_MAC_TABLE             1095
#define B_PASSWORD2                     1095
#define B_L3                            1095
#define R_TCP                           1096
#define B_MAC_TABLE                     1096
#define B_IPSEC                         1096
#define S_INFO                          1097
#define B_OPENVPN                       1097
#define B_DEFAULT                       1097
#define S_PORT                          1098
#define B_BRIDGE2                       1098
#define B_DDNS                          1098
#define S_INFO7                         1098
#define E_PORT                          1099
#define B_AZURE                         1099
#define S_INFO8                         1099
#define S_INTERVAL                      1100
#define E_CONTROLLER                    1100
#define B_IP_TABLE                      1100
#define E_PORT2                         1100
#define E_RADIUS_RETRY_INTERVAL         1100
#define S_INFO6                         1100
#define B_VPNGATE                       1100
#define S_INFO2                         1101
#define S_INTERVAL2                     1102
#define R_LOCAL                         1102
#define S_PROTOCOL                      1103
#define C_HOSTNAME                      1103
#define R_UDP                           1104
#define S_ICON                          1104
#define E_ALPHA_VALUE                   1105
#define S_INFO4                         1105
#define S_ICON2                         1105
#define S_INFO3                         1106
#define E_OLD_PASSWORD                  1106
#define E_NEW_PASSWORD1                 1107
#define S_INFO5                         1107
#define E_NEW_PASSWORD2                 1108
#define L_SETTING                       1109
#define B_NEW_SETTING                   1110
#define B_EDIT_SETTING                  1111
#define R_SERVER_ADMIN                  1111
#define B_DELETE_SETTING                1112
#define R_NO_SAVE                       1112
#define B_MODE                          1112
#define R_HUB_ADMIN                     1113
#define B_MODE2                         1113
#define B_VGC                           1113
#define S_HUBNAME                       1114
#define E_MAX_SESSION                   1115
#define R_LOCALHOST                     1116
#define L_HUB                           1118
#define L_LISTENER                      1120
#define B_SSL                           1121
#define B_STATUS                        1123
#define E_PASSWORD1                     1123
#define B_INFO                          1124
#define R_LIMIT_MAX_SESSION             1124
#define B_FARM                          1125
#define S_MAX_SESSION_1                 1125
#define B_INFO2                         1125
#define S_MAX_SESSION_2                 1126
#define B_CONNECTION                    1126
#define R_ONLINE                        1127
#define B_FARM_STATUS                   1127
#define R_OFFLINE                       1128
#define S_BOLD                          1129
#define S_FARM_INFO                     1130
#define S_BOLD2                         1130
#define R_STATIC                        1131
#define R_DYNAMIC                       1132
#define C_CIPHER                        1132
#define S_AO_3                          1133
#define S_ACL                           1134
#define B_VIEW                          1136
#define R_PKCS12                        1136
#define R_USE_PASS                      1137
#define E_PASS1                         1138
#define E_PASS2                         1139
#define R_X509_AND_KEY                  1140
#define S_PASS1                         1141
#define S_PASS2                         1142
#define B_DISCONNECT                    1143
#define R_SECURE                        1143
#define L_LIST                          1144
#define S_CURRENT                       1145
#define L_KEY                           1145
#define R_STANDALONE                    1146
#define R_CONTROLLER                    1147
#define R_MEMBER                        1148
#define S_PORT_2                        1151
#define S_PORT_1                        1152
#define S_IP_1                          1153
#define E_IP                            1154
#define S_SRC_MAC_ALL                   1154
#define S_CHECK_SRC_MAC                 1154
#define S_IP_2                          1155
#define E_SRC_MASK                      1155
#define E_MASK                          1155
#define S_CONTROLLER                    1156
#define E_DST_IP                        1156
#define E_DHCP_START                    1156
#define E_CONTROLLER_PORT               1157
#define E_DST_MASK                      1157
#define E_DHCP_END                      1157
#define S_PORT_3                        1158
#define E_DHCP_MASK                     1158
#define L_FARM_MEMBER                   1159
#define E_GATEWAY                       1159
#define B_USER                          1160
#define E_DNS                           1160
#define B_GROUP                         1161
#define B_CASCADE                       1161
#define E_DNS2                          1161
#define S_USER                          1162
#define B_USER2                         1162
#define S_GROUP                         1163
#define B_SECURENAT                     1163
#define B_ACCESS                        1164
#define S_LINK                          1165
#define S_RADIUS                        1166
#define L_USER                          1167
#define S_RADIUS2                       1167
#define S_CA                            1167
#define B_PROPERTY                      1168
#define B_RADIUS                        1169
#define B_LINK                          1170
#define S_PASSWORD_2                    1170
#define B_SESSION                       1171
#define S_PASSWORD_3                    1171
#define B_LOG                           1172
#define B_LOAD_CERT                     1172
#define B_RADIUS2                       1173
#define B_VIEW_CERT                     1173
#define B_CA                            1173
#define R_CN                            1174
#define B_SNAT                          1174
#define R_SERIAL                        1175
#define S_SNAT                          1175
#define R_O                             1175
#define R_SET_RADIUS_USERNAME           1176
#define B_CRL                           1176
#define R_OU                            1176
#define S_RADIUS_2                      1177
#define R_C                             1177
#define B_LOG_FILE                      1177
#define R_POLICY                        1178
#define S_RADIUS_4                      1178
#define R_ST                            1178
#define S_RADIUS_5                      1179
#define R_L                             1179
#define R_EXPIRES                       1180
#define R_SERI                          1180
#define S_RADIUS_7                      1180
#define R_MD5_HASH                      1181
#define S_RADIUS_9                      1181
#define R_SHA1_HASH                     1182
#define L_AUTH                          1183
#define S_RADIUS_8                      1183
#define S_RADIUS_1                      1184
#define S_RADIUS_3                      1185
#define S_POLICY_1                      1186
#define S_PASSWORD_1                    1187
#define S_POLICY_2                      1187
#define S_ROOT_CERT_1                   1188
#define S_ROOT_CERT_2                   1189
#define S_ROOT_CERT_3                   1190
#define S_USER_CERT_1                   1191
#define S_RADIUS_10                     1192
#define S_HINT                          1192
#define E_EXPIRES_DATE                  1193
#define S_POLICY_TITLE                  1194
#define E_POLICY_DESCRIPTION            1195
#define R_ENABLE                        1196
#define R_DISABLE                       1197
#define R_DEFINE                        1198
#define E_VALUE                         1199
#define S_TANI                          1200
#define S_LIMIT                         1201
#define L_GROUP                         1202
#define E_GROUPNAME                     1203
#define B_ADD                           1205
#define L_ACCESS_LIST                   1206
#define B_DEL_IF                        1206
#define B_ADD_TABLE                     1207
#define B_ADD_V6                        1207
#define R_PASS                          1208
#define B_DEL_TABLE                     1208
#define B_DEL                           1208
#define R_DISCARD                       1209
#define R_DENY                          1209
#define R_SRC_ALL                       1210
#define B_OBTAIN                        1210
#define R_IPV4                          1210
#define R_DST_ALL                       1211
#define R_IPV6                          1211
#define C_PROTOCOL                      1212
#define E_USERNAME1                     1213
#define E_USERNAME2                     1214
#define S_SRC_IP_1                      1215
#define S_SRC_IP_2                      1216
#define S_SRC_IP_3                      1217
#define E_SRC_IP                        1218
#define S_SRC_IP_4                      1218
#define S_IP_DST_1                      1219
#define S_IP_DST_2                      1220
#define S_IP_DST_3                      1221
#define S_TCP_1                         1222
#define S_TCP_2                         1223
#define S_TCP_3                         1224
#define S_TCP_4                         1225
#define S_TCP_5                         1226
#define S_TCP_6                         1227
#define S_TCP_7                         1228
#define B_USER1                         1229
#define S_SRC_MAC                       1230
#define R_USE_RADIUS                    1231
#define R_SRC_MAC_ALL                   1231
#define R_CHECK_SRC_MAC                 1231
#define S_DST_MAC                       1232
#define S_RADIUS3                       1233
#define R_DST_MAC_ALL                   1233
#define R_CHECK_DST_MAC                 1233
#define S_RADIUS_6                      1234
#define S_SRC_MAC_MASK                  1234
#define S_LOG                           1235
#define S_DST_MAC_MASK                  1235
#define S_MAC_NOTE                      1236
#define L_LINK                          1237
#define E_SERIAL                        1238
#define S_VLAN_GROUP                    1238
#define B_SEC                           1240
#define S_SEC                           1241
#define C_SEC_SWITCH                    1242
#define B_PACKET                        1243
#define S_PACKET                        1244
#define C_PACKET_SWITCH                 1245
#define S_PACKET_0                      1246
#define S_PACKET_1                      1247
#define B_PACKET_0_0                    1248
#define B_PACKET_1_0                    1249
#define S_FARM_INFO_1                   1249
#define B_PACKET_0_1                    1250
#define S_FARM_INFO_2                   1250
#define B_PACKET_1_1                    1251
#define L_TABLE                         1251
#define B_PACKET_0_2                    1252
#define R_ROOT_CERT                     1252
#define B_PACKET_1_2                    1253
#define R_SIGNED_CERT                   1253
#define S_PACKET_2                      1254
#define B_LOAD                          1254
#define B_PACKET_2_0                    1255
#define S_LOAD_1                        1255
#define B_PACKET_2_1                    1256
#define S_LOAD_2                        1256
#define B_PACKET_2_2                    1257
#define S_LOAD_3                        1257
#define S_LOAD_4                        1258
#define S_LOAD_5                        1259
#define S_STATIC_S                      1259
#define S_ACCESS                        1259
#define S_LOAD_6                        1260
#define S_VERSION                       1260
#define S_LOAD_7                        1261
#define S_LOGO                          1261
#define S_PACKET_3                      1262
#define S_LOAD_8                        1262
#define S_VERSION2                      1262
#define B_PACKET_3_0                    1263
#define S_LOAD_9                        1263
#define S_BUILD                         1263
#define B_PACKET_3_1                    1264
#define S_LOAD_10                       1264
#define B_PACKET_3_2                    1265
#define S_LOAD_11                       1265
#define B_SETTING                       1265
#define S_PACKET_4                      1266
#define B_CONNECT                       1266
#define S_ACCOUNT_NAME                  1266
#define S_LOAD_12                       1266
#define B_PACKET_4_0                    1267
#define S_ROUTER_LOGO                   1267
#define S_LOAD_13                       1267
#define B_PACKET_4_1                    1268
#define B_OPTION                        1268
#define E_MAC                           1268
#define B_PACKET_4_2                    1269
#define B_NAT                           1269
#define R_USE_NAT                       1269
#define S_PACKET_5                      1270
#define E_MTU                           1270
#define B_PACKET_5_0                    1271
#define B_DHCP                          1271
#define E_TCP                           1271
#define B_PACKET_5_1                    1272
#define E_UDP                           1272
#define B_PACKET_5_2                    1273
#define R_USE_DHCP                      1273
#define S_PACKET_6                      1274
#define R_SAVE_LOG                      1274
#define B_PACKET_6_0                    1275
#define R_HIDE                          1275
#define B_PACKET_6_1                    1276
#define S_PROPERTY                      1276
#define R_HIDE2                         1276
#define B_PACKET_6_2                    1277
#define B_ENABLE                        1277
#define S_PACKET_7                      1278
#define B_DISABLE                       1278
#define B_PACKET_7_0                    1279
#define B_CONFIG                        1279
#define B_CLONE                         1279
#define B_DISABLE2                      1279
#define B_PROXY                         1279
#define B_PACKET_7_1                    1280
#define S_TSUKUBA1                      1280
#define B_LICENSE                       1280
#define B_PACKET_7_2                    1281
#define S_TSUKUBA2                      1281
#define IDC_CHECK1                      1285
#define R_NO_SAVE_PASSWORD              1285
#define R_PROMISCUS                     1285
#define R_NO_ENUM                       1285
#define R_ETHERNET                      1285
#define R_CONTROLLER_ONLY               1285
#define B_HIDE                          1285
#define R_DISABLE_QOS                   1285
#define R_LOCK                          1285
#define C_REMOTE                        1285
#define C_DONTSHOWAGAIN                 1285
#define R_CHECK_TCP_STATE               1285
#define C_DELAY                         1285
#define C_USEMSG                        1285
#define R_L2TP_OVER_IPSEC               1285
#define B_AGREE                         1285
#define R_SHOWCUSTOM                    1285
#define B_RUN                           1285
#define B_DELETE_SENSITIVE              1285
#define R_LOG                           1285
#define R_DOUBLE                        1286
#define C_SITE                          1286
#define C_JITTER                        1286
#define R_REDIRECT                      1286
#define R_L2TP                          1286
#define E_LIST                          1287
#define C_OTHER                         1287
#define C_LOSS                          1287
#define R_L2TP_RAW                      1287
#define B_EASYMODE                      1287
#define R_ETHERIP                       1288
#define R_BRIDGE                        1289
#define R_TAP                           1290
#define R_MONITOR                       1290
#define E_TAPNAME                       1291
#define S_ETH_1                         1292
#define S_TAP_1                         1293
#define S_TAP_2                         1294
#define S_VHUB_BRIDGE                   1295
#define C_DEVICE                        1296
#define IDC_INFO                        1297
#define E_CONFIG                        1298
#define B_ADMINOPTION                   1300
#define S_AO_1                          1301
#define S_AO_2                          1302
#define S_ACL_3                         1303
#define S_ACL_2                         1304
#define B_ACL                           1305
#define B_ACL2                          1306
#define B_EXTOPTION                     1306
#define S_AO_4                          1307
#define B_MSG                           1308
#define C_NAME                          1309
#define S_ACL_5                         1310
#define L_IF                            1311
#define S_BOLD1                         1313
#define B_ADD_IF                        1314
#define E_NETWORK                       1315
#define E_METRIC                        1316
#define B_BOLD                          1317
#define R_CERT                          1319
#define R_KEY                           1320
#define E_STRING                        1320
#define R_DATA                          1321
#define B_BOLD1                         1321
#define B_BOLD2                         1322
#define R_FROM_FILE                     1322
#define R_FROM_SECURE                   1323
#define B_SELECT                        1324
#define S_FILE                          1325
#define S_PASS3                         1326
#define S_PASS4                         1327
#define E_PIN1                          1328
#define E_PIN2                          1329
#define E_PIN3                          1330
#define R_SINGLE                        1331
#define R_MASKED                        1332
#define S_MASK                          1333
#define S_MODE                          1336
#define B_PASSWORD                      1339
#define R_RECV_DISABLE                  1340
#define B_PASSWORD3                     1340
#define B_SPECIALLISTENER               1340
#define R_RECV_ENABLE                   1341
#define E_RECV                          1342
#define S_RECV                          1343
#define B_RECV                          1344
#define R_SEND_DISABLE                  1345
#define R_SEND_ENABLE                   1346
#define E_SEND                          1347
#define R_OPTIMIZE                      1347
#define S_SEND                          1348
#define R_MANUAL                        1348
#define B_SEND                          1349
#define R_NO                            1349
#define S_IMAGE                         1351
#define S_IMAGE2                        1352
#define S_INFO_1                        1352
#define S_INFO_2                        1353
#define S_IMAGE3                        1353
#define S_IMAGE_TSUKUBA                 1353
#define S_INFO_3                        1354
#define S_INFO_4                        1355
#define S_PROTOID                       1356
#define S_1                             1359
#define S_18                            1360
#define S_3                             1361
#define R_SERVER                        1362
#define S_19                            1362
#define R_CLIENT                        1363
#define S_20                            1363
#define S_4                             1364
#define S_21                            1364
#define S_5                             1365
#define S_23                            1365
#define C_HOST                          1366
#define S_22                            1366
#define S_6                             1367
#define S_25                            1367
#define S_8                             1368
#define S_9                             1369
#define S_7                             1370
#define R_DOWNLOAD                      1371
#define R_UPLOAD                        1372
#define R_FULL                          1373
#define S_10                            1374
#define S_11                            1375
#define C_NUM                           1376
#define S_12                            1377
#define E_SPAN                          1378
#define S_13                            1379
#define E_EDIT                          1379
#define S_14                            1380
#define IDC_EDIT1                       1380
#define E_WEIGHT                        1380
#define B_KEY1                          1380
#define E_SYSLOG_HOSTNAME               1380
#define E_TEXT                          1380
#define E_DELAY                         1380
#define E_IPV6                          1380
#define E_SECRET                        1380
#define E_ID                            1380
#define E_DDNS_HOST                     1380
#define E_SAMPLE1                       1380
#define E_CURRENT                       1380
#define E_OWNER                         1380
#define S_15                            1381
#define S_2                             1381
#define E_SYSLOG_PORT                   1381
#define E_JITTER                        1381
#define E_IPV7                          1381
#define E_MASKV6                        1381
#define E_SAMPLE2                       1381
#define E_DDNS_HOST2                    1381
#define E_AZURE_HOST                    1381
#define E_LOSS                          1382
#define S_16                            1382
#define E_URL                           1382
#define E_ABUSE                         1382
#define S_17                            1383
#define E_MSG                           1383
#define S_24                            1384
#define ABOUT                           1387
#define C_SYSLOG                        1388
#define B_KEY2                          1389
#define S_01                            1389
#define B_KEY3                          1390
#define S_02                            1390
#define B_KEY4                          1391
#define R_EASY                          1391
#define B_KEY5                          1392
#define R_NORMAL                        1392
#define B_KEY6                          1393
#define S_PASSWORD1                     1393
#define S_PASSWORD2                     1394
#define S_PASSWORD3                     1395
#define S_STATIC3                       1397
#define S_STATIC4                       1398
#define S_STATIC5                       1399
#define S_STATIC7                       1400
#define S_STATIC66                      1401
#define S_STATIC2                       1402
#define S_STATIC11                      1403
#define S_STATIC1                       1404
#define S_STATIC6                       1405
#define S_STATIC8                       1406
#define S_STATIC9                       1407
#define S_STATIC10                      1408
#define S_STATIC12                      1409
#define S_STATIC19                      1410
#define S_STATIC133                     1411
#define S_REMOTE_1                      1413
#define S_SITE_1                        1414
#define S_SITE_2                        1415
#define C_CENTER                        1416
#define C_EDGE                          1417
#define S_OTHER                         1418
#define S_1_1                           1421
#define S_1_2                           1422
#define S_2_1                           1423
#define S_2_2                           1424
#define S_3_1                           1425
#define S_3_2                           1426
#define IDC_COMBO1                      1427
#define C_BITS                          1427
#define R_NEVER                         1427
#define IDC_BUTTON1                     1428
#define BMP_UT                          1428
#define S_LICENSE                       1429
#define IDC_BUTTON2                     1429
#define S_BETA                          1430
#define IDC_BUTTON3                     1430
#define S_DST_MAC_ALL                   1431
#define S_CHECK_DST_MAC                 1431
#define IDC_BUTTON4                     1431
#define S_ACCESS_DST_ALL                1432
#define S_ACCESS_SRC_ALL                1433
#define IDC_RADIO1                      1434
#define R_ESTABLISHED                   1434
#define R_SYSTEM                        1434
#define R_DEFAULT                       1434
#define S_ENABLE                        1434
#define R_2WEEKS                        1434
#define IDC_RADIO2                      1435
#define R_UNESTABLISHED                 1435
#define R_USER                          1435
#define R_CUSTOM                        1435
#define S_DISBLE                        1435
#define R_PERMANENT                     1435
#define R_FOR_SYSTEM                    1436
#define IDC_NETADDRESS1                 1437
#define R_FOR_USER                      1437
#define IDC_PROGRESS1                   1438
#define E_HELP                          1440
#define S_DELAY                         1441
#define S_DELAY2                        1442
#define S_JITTER                        1443
#define S_JITTER2                       1444
#define S_LOSS                          1445
#define S_LOSS2                         1446
#define S_STATIC14                      1448
#define S_STATIC15                      1449
#define S_MSG_4                         1450
#define S_STATUS1                       1451
#define S_STATUS2                       1452
#define P_BAR                           1453
#define L_HUBNAME                       1454
#define S_PSK                           1455
#define S_PSK2                          1456
#define S_WIN8                          1457
#define R_OPENVPN                       1458
#define S_UDP                           1459
#define S_UDP2                          1460
#define S_TOOL                          1461
#define S_TOOL2                         1462
#define R_SSTP                          1463
#define B_CONFIG_L3                     1464
#define S_SSTP                          1465
#define E_HOST                          1466
#define E_IPV4                          1467
#define E_NEWHOST                       1468
#define B_NSLOOKUP                      1469
#define E_KEY                           1469
#define B_HINT                          1470
#define S_DDNS                          1470
#define R_OVER_ICMP                     1471
#define S_AZURE                         1471
#define B_HINT2                         1471
#define R_OVER_ICMP2                    1472
#define R_OVER_DNS                      1472
#define B_WIZ_NEXT                      1472
#define B_WIZ_NEXT2                     1473
#define B_WIZ_PREV                      1473
#define S_ACK                           1473
#define S_WELCOME                       1474
#define S_ACK2                          1475
#define S_WELCOME2                      1475
#define S_WELCOME3                      1476
#define E_DIR                           1479
#define B_BROWSE                        1480
#define S_DEST                          1481
#define B_BROWSE_OUT                    1481
#define S_UAC                           1482
#define E_SETTING                       1483
#define E_OUT                           1484
#define B_BROWSE_SETTING                1485
#define S_INFO1                         1486
#define S_PRODUCT                       1487
#define S_INFO9                         1487
#define S_PRODUCT_STR                   1488
#define S_CURRENT_STR                   1490
#define S_LATEST                        1491
#define S_LATEST_STR                    1492
#define S_BMP_EN                        1494
#define S_BMP_JA                        1495
#define B_CHANGE                        1496
#define S_HOSTNAME_BORDER               1497
#define S_HOSTNAME_INFO                 1498
#define S_BMP_CN                        1499
#define S_REFRESH                       1499
#define S_VLAN                          1500
#define C_VLAN                          1502
#define S_VPNGATEJA                     1504
#define S_ICO_VPNGATE                   1505
#define S_VPNGATEJA2                    1505
#define S_VPNGATEEN                     1505
#define S1                              1506
#define S2                              1507
#define S3                              1508
#define S4                              1509
#define S5                              1510
#define S_VGS1                          1511
#define S_VGS2                          1512
#define B_VGS                           1513
#define S_VGS3                          1514
#define S_TSUKUBA                       1515
#define R_DISABLE_NATT                  1516
#define S_SMARTCARD_ICON                1517
#define B_ONLINE                        1655
#define D_NM_CONNECT                    1998
#define D_NM_MAIN                       1999
#define D_NM_OPTION                     2000
#define D_NM_NAT                        2001
#define D_NM_DHCP                       2002
#define D_NM_CHANGE_PASSWORD            2003
#define D_SM_SNAT                       2004
#define D_SM_BRIDGE                     2005
#define D_WIN9X_REBOOT                  2006
#define D_DEFAULT1                      2007
#define D_EM_MAIN                       2008
#define D_EM_ADD                        2009
#define D_EM_PASSWORD                   2010
#define D_SM_CONFIG                     2011
#define D_SM_ADMIN_OPTION               2012
#define D_SM_AO_VALUE                   2013
#define D_SM_L3                         2014
#define D_SM_L3_ADD                     2015
#define D_SM_L3_SW                      2016
#define D_SM_L3_SW_IF                   2017
#define D_SM_L3_SW_TABLE                2018
#define D_CM_SELECT_SECURE              2019
#define D_CM_SECURE_MANAGER             2020
#define D_CM_SECURE_TYPE                2021
#define D_STRING                        2022
#define D_SM_SELECT_KEYPAIR             2023
#define D_CM_LOAD_X                     2024
#define D_CM_SECURE_PIN                 2025
#define D_SM_CRL                        2026
#define D_SM_EDIT_CRL                   2027
#define D_SM_AC_LIST                    2028
#define D_SM_AC                         2029
#define D_SM_LOG_FILE                   2030
#define D_SM_READ_LOG_FILE              2031
#define D_SM_SAVE_LOG                   2032
#define D_TCP                           2033
#define D_TCP_MSG                       2034
#define D_CM_PKCSEULA                   2035
#define D_CM_KAKUSHI                    2036
#define D_CM_TRAFFIC                    2037
#define D_CM_TRAFFIC_RUN                2038
#define D_CM_TRAFFIC_RESULT             2039
#define D_SM_LICENSE                    2040
#define D_SM_LICENSE_ADD                2041
#define D_FREEEDITION                   2042
#define D_FREEINFO                      2042
#define D_EM_LICENSE_ADD                2043
#define D_EM_LICENSE                    2044
#define D_EM_REMOTE                     2045
#define D_CM_SETTING                    2046
#define D_CM_EASY                       2047
#define D_SM_SETUP                      2048
#define D_SM_SETUP_HUB                  2049
#define D_SM_SETUP_STEP                 2050
#define D_DEFAULT2                      2051
#define D_CPU64_WARNING                 2051
#define D_ONCEMSG                       2052
#define D_CONNECT                       2053
#define D_SM_SIMULATION                 2054
#define D_SM_EDIT_ACCESS1               2055
#define D_SM_EDIT_ACCESS_V6             2055
#define D_SM_VLAN                       2056
#define D_SM_MSG                        2057
#define D_NICSTATUS                     2058
#define D_NICINFO                       2058
#define D_SM_IPSEC                      2059
#define D_SM_ETHERIP                    2060
#define D_SM_ETHERIP_ID                 2061
#define D_SM_OPENVPN                    2062
#define D_DDNS                          2063
#define D_SM_DDNS                       2063
#define D_SM_SPECIALLISTENER            2064
#define D_SM_REDIRECT                   2065
#define D_SW_TEST1                      2066
#define D_DUMMY                         2067
#define D_SW_TEST2                      2068
#define D_SW_DEFAULT                    2069
#define D_SW_WELCOME                    2070
#define D_SW_MODE                       2071
#define D_SW_NOT_ADMIN                  2072
#define D_SW_COMPONENTS                 2073
#define D_SW_EULA                       2074
#define D_SW_WARNING                    2075
#define D_SW_DIR                        2076
#define D_SW_READY                      2077
#define D_SW_PERFORM                    2078
#define D_SW_ERROR                      2079
#define D_SW_ERROR1                     2080
#define D_SW_FINISH                     2080
#define D_SW_WELCOME1                   2081
#define D_SW_UNINST1                    2081
#define D_SW_LANG1                      2082
#define D_SW_EASY1                      2083
#define D_SW_EASY2                      2084
#define D_SW_WEB1                       2085
#define D_SW_EASY4                      2086
#define D_SW_WEB2                       2086
#define D_UPDATE_NOTICE                 2087
#define D_UPDATE_CONFIG                 2088
#define D_SM_VMBRIDGE                   2089
#define D_SM_AZURE                      2090
#define D_SM_PROXY                      2091
#define D_VGC_LIST                      2092
#define D_VGC_PROTOCOL                  2093
#define D_VGS_CONFIG                    2094
#define D_VGS_OPTION                    2095
#define D_VGS_WARNING                   2096
#define D_DEFAULT3                      2097
#define D_NM_PUSH                       2097
#define ID_Menu40011                    40011
#define CMD_CONNECT                     40020
#define CMD_STATUS                      40021
#define CMD_DISCONNECT                  40022
#define CMD_NEW                         40023
#define CMD_CLONE                       40024
#define CMD_STARTUP                     40025
#define CMD_NOSTARTUP                   40026
#define CMD_PROPERTY                    40028
#define CMD_EXIT                        40029
#define CMD_SWITCH_SELECT               40031
#define CMD_SELECT_ALL                  40032
#define CMD_TOOLBAR                     40033
#define CMD_STATUSBAR                   40034
#define CMD_ICON                        40035
#define CMD_DETAIL                      40036
#define CMD_REFRESH                     40037
#define CMD_PASSWORD                    40038
#define CMD_ABOUT                       40040
#define CMD_DELETE_VLAN                 40045
#define CMD_NEW_VLAN                    40046
#define CMD_REINSTALL                   40050
#define CMD_PROPERTY_VLAN               40052
#define CMD_DISABLE_VLAN                40054
#define CMD_ENABLE_VLAN                 40056
#define CMD_RENAME                      40059
#define CMD_DELETE                      40061
#define CMD_GRID                        40062
#define CMD_                            40063
#define CMD_TRUST                       40065
#define CMD_DISCONNECT_ALL              40067
#define CMD_VOICE_NORMAL                40072
#define CMD_VOIDE_NONE                  40073
#define CMD_VOICE_ODD                   40074
#define CMD_EXPORT_ACCOUNT              40075
#define CMD_IMPORT_ACCOUNT              40078
#define CMD_SHORTCUT                    40079
#define ID_40080                        40080
#define ID_40082                        40082
#define CMD_SECURE_MANAGER              40083
#define CMD_SECURE_SELECT               40084
#define CMD_QUIT                        40086
#define CMD_NETIF                       40088
#define CMD_TCPIP                       40089
#define CMD_TRAFFIC                     40090
#define CMD_OPTION                      40092
#define ID__40093                       40093
#define CMD_CM_SETTING                  40094
#define CMD_MMCSS                       40095
#define CMD_TRAYICON                    40096
#define ID__                            40097
#define CMD_WINNET                      40098
#define ID__40099                       40099
#define CMD_VISTASTYLE                  40100
#define ID__40101                       40101
#define CMD_SHOWPORT                    40102
#define ID__40103                       40103
#define CMD_RECENT                      40104
#define ID__40105                       40105
#define ID__40106                       40106
#define CMD_LANGUAGE                    40107
#define ID_VPNGATE40108                 40108
#define ID__40109                       40109
#define CMD_VGS                         40110

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        242
#define _APS_NEXT_COMMAND_VALUE         40111
#define _APS_NEXT_CONTROL_VALUE         1518
#define _APS_NEXT_SYMED_VALUE           102
#endif
#endif
